@@ -1,13 +1,13 @@
-## ----include=FALSE-------------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 library(IndexNumR)
 
-## ------------------------------------------------------------------------
+## ----head_CES-----------------------------------------------------------------
 head(CES_sigma_2)
 
-## ------------------------------------------------------------------------
+## ----head_CES_ordered---------------------------------------------------------
 head(CES_sigma_2[order(CES_sigma_2$time),])
 
-## ------------------------------------------------------------------------
+## ----bilateral_examples-------------------------------------------------------
 priceIndex(CES_sigma_2,
            pvar = "prices",
            qvar = "quantities",
@@ -16,7 +16,7 @@ priceIndex(CES_sigma_2,
            indexMethod = "laspeyres", 
            output = "chained")
 
-## ------------------------------------------------------------------------
+## ----multiple_bilateral-------------------------------------------------------
 methods <- c("laspeyres","paasche","fisher","tornqvist")
 prices <- lapply(methods, 
                  function(x) {priceIndex(CES_sigma_2,
@@ -29,7 +29,7 @@ prices <- lapply(methods,
 
 as.data.frame(prices, col.names = methods)
 
-## ------------------------------------------------------------------------
+## ----elasticity---------------------------------------------------------------
 elasticity(CES_sigma_2, 
            pvar="prices",
            qvar="quantities",
@@ -37,7 +37,7 @@ elasticity(CES_sigma_2,
            prodID="prodID",
            compIndex="ces")
 
-## ------------------------------------------------------------------------
+## ----relative_dissimilarity---------------------------------------------------
 lq <- relativeDissimilarity(CES_sigma_2, 
                             pvar="prices", 
                             qvar="quantities", 
@@ -48,10 +48,10 @@ lq <- relativeDissimilarity(CES_sigma_2,
 
 head(lq)
 
-## ------------------------------------------------------------------------
+## ----similarity_links---------------------------------------------------------
 maximumSimilarityLinks(lq)
 
-## ------------------------------------------------------------------------
+## ----index_similarity---------------------------------------------------------
 priceIndex(CES_sigma_2,
            pvar = "prices",
            qvar = "quantities",
@@ -61,17 +61,31 @@ priceIndex(CES_sigma_2,
            output = "chained", 
            chainMethod = "logquadratic")
 
-## ------------------------------------------------------------------------
-GEKSIndex(CES_sigma_2, 
+## ----geks_splicing------------------------------------------------------------
+# Assume that the data in CES_sigma_2 are quarterly data with time period
+# 1 corresponding to the December quarter. 
+
+splices <- c("window", "half", "movement", "mean", "fbew", "fbmw")
+
+# estimate a GEKS index using the different splicing methods. Under
+# the above assumptions, the window must be 5 to ensure the base period is
+# each December quarter.
+result <- as.data.frame(lapply(splices, function(x){
+  GEKSIndex(CES_sigma_2, 
           pvar = "prices", 
           qvar = "quantities", 
           pervar = "time", 
           prodID = "prodID", 
           indexMethod = "tornqvist", 
-          window=11, 
-          splice = "mean")
+          window=5, 
+          splice = x)
+}))
 
-## ----indicators----------------------------------------------------------
+colnames(result) <- splices
+result
+
+
+## ----indicators---------------------------------------------------------------
 
 methods <- c("laspeyres", "paasche", "bennet", "montgomery")
 
@@ -85,7 +99,7 @@ p <- lapply(methods, function(x) {priceIndicator(CES_sigma_2,
 as.data.frame(p, col.names = methods)
 
 
-## ----value---------------------------------------------------------------
+## ----value--------------------------------------------------------------------
 
 valueDecomposition(CES_sigma_2, 
                    pvar = "prices",  
